# ProtobufListValue

`ListValue` is a wrapper around a repeated field of values.  The JSON representation for `ListValue` is JSON array.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**values** | [**list[ProtobufValue]**](ProtobufValue.md) | Repeated field of dynamically typed values. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


